@@ -1,10 +1,10 @@
 ;; -*- no-byte-compile: t; lexical-binding: nil -*-
-(define-package "sol-mode" "0.1.0"
+(define-package "sol-mode" "20250805.2103"
   "Major mode for editing Solidity code."
   '((emacs "30.1"))
   :url "https://codeberg.org/nlordell/sol-mode"
-  :commit "93d96af2b7d19edd9caaf35478ec88e1530785aa"
-  :revdesc "v0.1.0-0-g93d96af2b7d1"
+  :commit "1379290f360fb3fea98ae397996b08d32372d77d"
+  :revdesc "1379290f360f"
   :keywords '("solidity" "languages")
   :authors '(("Nicholas Rodrigues Lordello" . "n@lordello.net"))
   :maintainers '(("Nicholas Rodrigues Lordello" . "n@lordello.net")))
