@@ -5,8 +5,8 @@
 ;; Author:   Nicholas Rodrigues Lordello <n@lordello.net>
 ;; URL:      https://codeberg.org/nlordell/sol-mode
 ;; Keywords: solidity languages
-;; Package-Version: 0.1.0
-;; Package-Revision: v0.1.0-0-g93d96af2b7d1
+;; Package-Version: 20250805.2103
+;; Package-Revision: 1379290f360f
 ;; Package-Requires: ((emacs "30.1"))
 
 ;; This program is free software: you can redistribute it and/or modify
@@ -241,7 +241,7 @@
      (((comment) @font-lock-preprocessor-face)
       (:match "\\`/// @solidity" @font-lock-preprocessor-face))
      (((comment) @font-lock-doc-face)
-      (:match "\\`\\(?:///[^/]\\|/\\*\\*[^*]\\)" @font-lock-doc-face))
+      (:match "\\`\\(?:///[^/]\\|///\\'\\|/\\*\\*[^*]\\)" @font-lock-doc-face))
      (comment) @font-lock-comment-face))
   "Font-lock settings for `sol-mode' buffers.")
 
